@@ -46,77 +46,77 @@ __all__ = (
     "BackendAPIResourceConfigTypeDef",
     "BackendAuthSocialProviderConfigTypeDef",
     "BackendJobRespObjTypeDef",
-    "CloneBackendRequestTypeDef",
-    "CloneBackendResponseResponseTypeDef",
-    "CreateBackendAPIRequestTypeDef",
-    "CreateBackendAPIResponseResponseTypeDef",
+    "CloneBackendRequestRequestTypeDef",
+    "CloneBackendResponseTypeDef",
+    "CreateBackendAPIRequestRequestTypeDef",
+    "CreateBackendAPIResponseTypeDef",
     "CreateBackendAuthForgotPasswordConfigTypeDef",
     "CreateBackendAuthIdentityPoolConfigTypeDef",
     "CreateBackendAuthMFAConfigTypeDef",
     "CreateBackendAuthOAuthConfigTypeDef",
     "CreateBackendAuthPasswordPolicyConfigTypeDef",
-    "CreateBackendAuthRequestTypeDef",
+    "CreateBackendAuthRequestRequestTypeDef",
     "CreateBackendAuthResourceConfigTypeDef",
-    "CreateBackendAuthResponseResponseTypeDef",
+    "CreateBackendAuthResponseTypeDef",
     "CreateBackendAuthUserPoolConfigTypeDef",
-    "CreateBackendConfigRequestTypeDef",
-    "CreateBackendConfigResponseResponseTypeDef",
-    "CreateBackendRequestTypeDef",
-    "CreateBackendResponseResponseTypeDef",
-    "CreateTokenRequestTypeDef",
-    "CreateTokenResponseResponseTypeDef",
-    "DeleteBackendAPIRequestTypeDef",
-    "DeleteBackendAPIResponseResponseTypeDef",
-    "DeleteBackendAuthRequestTypeDef",
-    "DeleteBackendAuthResponseResponseTypeDef",
-    "DeleteBackendRequestTypeDef",
-    "DeleteBackendResponseResponseTypeDef",
-    "DeleteTokenRequestTypeDef",
-    "DeleteTokenResponseResponseTypeDef",
+    "CreateBackendConfigRequestRequestTypeDef",
+    "CreateBackendConfigResponseTypeDef",
+    "CreateBackendRequestRequestTypeDef",
+    "CreateBackendResponseTypeDef",
+    "CreateTokenRequestRequestTypeDef",
+    "CreateTokenResponseTypeDef",
+    "DeleteBackendAPIRequestRequestTypeDef",
+    "DeleteBackendAPIResponseTypeDef",
+    "DeleteBackendAuthRequestRequestTypeDef",
+    "DeleteBackendAuthResponseTypeDef",
+    "DeleteBackendRequestRequestTypeDef",
+    "DeleteBackendResponseTypeDef",
+    "DeleteTokenRequestRequestTypeDef",
+    "DeleteTokenResponseTypeDef",
     "EmailSettingsTypeDef",
-    "GenerateBackendAPIModelsRequestTypeDef",
-    "GenerateBackendAPIModelsResponseResponseTypeDef",
-    "GetBackendAPIModelsRequestTypeDef",
-    "GetBackendAPIModelsResponseResponseTypeDef",
-    "GetBackendAPIRequestTypeDef",
-    "GetBackendAPIResponseResponseTypeDef",
-    "GetBackendAuthRequestTypeDef",
-    "GetBackendAuthResponseResponseTypeDef",
-    "GetBackendJobRequestTypeDef",
-    "GetBackendJobResponseResponseTypeDef",
-    "GetBackendRequestTypeDef",
-    "GetBackendResponseResponseTypeDef",
-    "GetTokenRequestTypeDef",
-    "GetTokenResponseResponseTypeDef",
-    "ImportBackendAuthRequestTypeDef",
-    "ImportBackendAuthResponseResponseTypeDef",
-    "ListBackendJobsRequestTypeDef",
-    "ListBackendJobsResponseResponseTypeDef",
+    "GenerateBackendAPIModelsRequestRequestTypeDef",
+    "GenerateBackendAPIModelsResponseTypeDef",
+    "GetBackendAPIModelsRequestRequestTypeDef",
+    "GetBackendAPIModelsResponseTypeDef",
+    "GetBackendAPIRequestRequestTypeDef",
+    "GetBackendAPIResponseTypeDef",
+    "GetBackendAuthRequestRequestTypeDef",
+    "GetBackendAuthResponseTypeDef",
+    "GetBackendJobRequestRequestTypeDef",
+    "GetBackendJobResponseTypeDef",
+    "GetBackendRequestRequestTypeDef",
+    "GetBackendResponseTypeDef",
+    "GetTokenRequestRequestTypeDef",
+    "GetTokenResponseTypeDef",
+    "ImportBackendAuthRequestRequestTypeDef",
+    "ImportBackendAuthResponseTypeDef",
+    "ListBackendJobsRequestRequestTypeDef",
+    "ListBackendJobsResponseTypeDef",
     "LoginAuthConfigReqObjTypeDef",
     "PaginatorConfigTypeDef",
-    "RemoveAllBackendsRequestTypeDef",
-    "RemoveAllBackendsResponseResponseTypeDef",
-    "RemoveBackendConfigRequestTypeDef",
-    "RemoveBackendConfigResponseResponseTypeDef",
+    "RemoveAllBackendsRequestRequestTypeDef",
+    "RemoveAllBackendsResponseTypeDef",
+    "RemoveBackendConfigRequestRequestTypeDef",
+    "RemoveBackendConfigResponseTypeDef",
     "ResponseMetadataTypeDef",
     "SettingsTypeDef",
     "SmsSettingsTypeDef",
     "SocialProviderSettingsTypeDef",
-    "UpdateBackendAPIRequestTypeDef",
-    "UpdateBackendAPIResponseResponseTypeDef",
+    "UpdateBackendAPIRequestRequestTypeDef",
+    "UpdateBackendAPIResponseTypeDef",
     "UpdateBackendAuthForgotPasswordConfigTypeDef",
     "UpdateBackendAuthIdentityPoolConfigTypeDef",
     "UpdateBackendAuthMFAConfigTypeDef",
     "UpdateBackendAuthOAuthConfigTypeDef",
     "UpdateBackendAuthPasswordPolicyConfigTypeDef",
-    "UpdateBackendAuthRequestTypeDef",
+    "UpdateBackendAuthRequestRequestTypeDef",
     "UpdateBackendAuthResourceConfigTypeDef",
-    "UpdateBackendAuthResponseResponseTypeDef",
+    "UpdateBackendAuthResponseTypeDef",
     "UpdateBackendAuthUserPoolConfigTypeDef",
-    "UpdateBackendConfigRequestTypeDef",
-    "UpdateBackendConfigResponseResponseTypeDef",
-    "UpdateBackendJobRequestTypeDef",
-    "UpdateBackendJobResponseResponseTypeDef",
+    "UpdateBackendConfigRequestRequestTypeDef",
+    "UpdateBackendConfigResponseTypeDef",
+    "UpdateBackendJobRequestRequestTypeDef",
+    "UpdateBackendJobResponseTypeDef",
 )
 
 BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
@@ -200,8 +200,8 @@ class BackendJobRespObjTypeDef(
     pass
 
 
-CloneBackendRequestTypeDef = TypedDict(
-    "CloneBackendRequestTypeDef",
+CloneBackendRequestRequestTypeDef = TypedDict(
+    "CloneBackendRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -209,8 +209,8 @@ CloneBackendRequestTypeDef = TypedDict(
     },
 )
 
-CloneBackendResponseResponseTypeDef = TypedDict(
-    "CloneBackendResponseResponseTypeDef",
+CloneBackendResponseTypeDef = TypedDict(
+    "CloneBackendResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -222,8 +222,8 @@ CloneBackendResponseResponseTypeDef = TypedDict(
     },
 )
 
-CreateBackendAPIRequestTypeDef = TypedDict(
-    "CreateBackendAPIRequestTypeDef",
+CreateBackendAPIRequestRequestTypeDef = TypedDict(
+    "CreateBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -232,8 +232,8 @@ CreateBackendAPIRequestTypeDef = TypedDict(
     },
 )
 
-CreateBackendAPIResponseResponseTypeDef = TypedDict(
-    "CreateBackendAPIResponseResponseTypeDef",
+CreateBackendAPIResponseTypeDef = TypedDict(
+    "CreateBackendAPIResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -344,8 +344,8 @@ class CreateBackendAuthPasswordPolicyConfigTypeDef(
     pass
 
 
-CreateBackendAuthRequestTypeDef = TypedDict(
-    "CreateBackendAuthRequestTypeDef",
+CreateBackendAuthRequestRequestTypeDef = TypedDict(
+    "CreateBackendAuthRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -377,8 +377,8 @@ class CreateBackendAuthResourceConfigTypeDef(
     pass
 
 
-CreateBackendAuthResponseResponseTypeDef = TypedDict(
-    "CreateBackendAuthResponseResponseTypeDef",
+CreateBackendAuthResponseTypeDef = TypedDict(
+    "CreateBackendAuthResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -416,14 +416,14 @@ class CreateBackendAuthUserPoolConfigTypeDef(
     pass
 
 
-_RequiredCreateBackendConfigRequestTypeDef = TypedDict(
-    "_RequiredCreateBackendConfigRequestTypeDef",
+_RequiredCreateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateBackendConfigRequestRequestTypeDef",
     {
         "AppId": str,
     },
 )
-_OptionalCreateBackendConfigRequestTypeDef = TypedDict(
-    "_OptionalCreateBackendConfigRequestTypeDef",
+_OptionalCreateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateBackendConfigRequestRequestTypeDef",
     {
         "BackendManagerAppId": str,
     },
@@ -431,14 +431,15 @@ _OptionalCreateBackendConfigRequestTypeDef = TypedDict(
 )
 
 
-class CreateBackendConfigRequestTypeDef(
-    _RequiredCreateBackendConfigRequestTypeDef, _OptionalCreateBackendConfigRequestTypeDef
+class CreateBackendConfigRequestRequestTypeDef(
+    _RequiredCreateBackendConfigRequestRequestTypeDef,
+    _OptionalCreateBackendConfigRequestRequestTypeDef,
 ):
     pass
 
 
-CreateBackendConfigResponseResponseTypeDef = TypedDict(
-    "CreateBackendConfigResponseResponseTypeDef",
+CreateBackendConfigResponseTypeDef = TypedDict(
+    "CreateBackendConfigResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -448,16 +449,16 @@ CreateBackendConfigResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateBackendRequestTypeDef = TypedDict(
-    "_RequiredCreateBackendRequestTypeDef",
+_RequiredCreateBackendRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateBackendRequestRequestTypeDef",
     {
         "AppId": str,
         "AppName": str,
         "BackendEnvironmentName": str,
     },
 )
-_OptionalCreateBackendRequestTypeDef = TypedDict(
-    "_OptionalCreateBackendRequestTypeDef",
+_OptionalCreateBackendRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateBackendRequestRequestTypeDef",
     {
         "ResourceConfig": Dict[str, Any],
         "ResourceName": str,
@@ -466,14 +467,14 @@ _OptionalCreateBackendRequestTypeDef = TypedDict(
 )
 
 
-class CreateBackendRequestTypeDef(
-    _RequiredCreateBackendRequestTypeDef, _OptionalCreateBackendRequestTypeDef
+class CreateBackendRequestRequestTypeDef(
+    _RequiredCreateBackendRequestRequestTypeDef, _OptionalCreateBackendRequestRequestTypeDef
 ):
     pass
 
 
-CreateBackendResponseResponseTypeDef = TypedDict(
-    "CreateBackendResponseResponseTypeDef",
+CreateBackendResponseTypeDef = TypedDict(
+    "CreateBackendResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -485,15 +486,15 @@ CreateBackendResponseResponseTypeDef = TypedDict(
     },
 )
 
-CreateTokenRequestTypeDef = TypedDict(
-    "CreateTokenRequestTypeDef",
+CreateTokenRequestRequestTypeDef = TypedDict(
+    "CreateTokenRequestRequestTypeDef",
     {
         "AppId": str,
     },
 )
 
-CreateTokenResponseResponseTypeDef = TypedDict(
-    "CreateTokenResponseResponseTypeDef",
+CreateTokenResponseTypeDef = TypedDict(
+    "CreateTokenResponseTypeDef",
     {
         "AppId": str,
         "ChallengeCode": str,
@@ -503,16 +504,16 @@ CreateTokenResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteBackendAPIRequestTypeDef = TypedDict(
-    "_RequiredDeleteBackendAPIRequestTypeDef",
+_RequiredDeleteBackendAPIRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
     },
 )
-_OptionalDeleteBackendAPIRequestTypeDef = TypedDict(
-    "_OptionalDeleteBackendAPIRequestTypeDef",
+_OptionalDeleteBackendAPIRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteBackendAPIRequestRequestTypeDef",
     {
         "ResourceConfig": "BackendAPIResourceConfigTypeDef",
     },
@@ -520,14 +521,14 @@ _OptionalDeleteBackendAPIRequestTypeDef = TypedDict(
 )
 
 
-class DeleteBackendAPIRequestTypeDef(
-    _RequiredDeleteBackendAPIRequestTypeDef, _OptionalDeleteBackendAPIRequestTypeDef
+class DeleteBackendAPIRequestRequestTypeDef(
+    _RequiredDeleteBackendAPIRequestRequestTypeDef, _OptionalDeleteBackendAPIRequestRequestTypeDef
 ):
     pass
 
 
-DeleteBackendAPIResponseResponseTypeDef = TypedDict(
-    "DeleteBackendAPIResponseResponseTypeDef",
+DeleteBackendAPIResponseTypeDef = TypedDict(
+    "DeleteBackendAPIResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -539,8 +540,8 @@ DeleteBackendAPIResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteBackendAuthRequestTypeDef = TypedDict(
-    "DeleteBackendAuthRequestTypeDef",
+DeleteBackendAuthRequestRequestTypeDef = TypedDict(
+    "DeleteBackendAuthRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -548,8 +549,8 @@ DeleteBackendAuthRequestTypeDef = TypedDict(
     },
 )
 
-DeleteBackendAuthResponseResponseTypeDef = TypedDict(
-    "DeleteBackendAuthResponseResponseTypeDef",
+DeleteBackendAuthResponseTypeDef = TypedDict(
+    "DeleteBackendAuthResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -561,16 +562,16 @@ DeleteBackendAuthResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteBackendRequestTypeDef = TypedDict(
-    "DeleteBackendRequestTypeDef",
+DeleteBackendRequestRequestTypeDef = TypedDict(
+    "DeleteBackendRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
     },
 )
 
-DeleteBackendResponseResponseTypeDef = TypedDict(
-    "DeleteBackendResponseResponseTypeDef",
+DeleteBackendResponseTypeDef = TypedDict(
+    "DeleteBackendResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -582,16 +583,16 @@ DeleteBackendResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteTokenRequestTypeDef = TypedDict(
-    "DeleteTokenRequestTypeDef",
+DeleteTokenRequestRequestTypeDef = TypedDict(
+    "DeleteTokenRequestRequestTypeDef",
     {
         "AppId": str,
         "SessionId": str,
     },
 )
 
-DeleteTokenResponseResponseTypeDef = TypedDict(
-    "DeleteTokenResponseResponseTypeDef",
+DeleteTokenResponseTypeDef = TypedDict(
+    "DeleteTokenResponseTypeDef",
     {
         "IsSuccess": bool,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -607,8 +608,8 @@ EmailSettingsTypeDef = TypedDict(
     total=False,
 )
 
-GenerateBackendAPIModelsRequestTypeDef = TypedDict(
-    "GenerateBackendAPIModelsRequestTypeDef",
+GenerateBackendAPIModelsRequestRequestTypeDef = TypedDict(
+    "GenerateBackendAPIModelsRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -616,8 +617,8 @@ GenerateBackendAPIModelsRequestTypeDef = TypedDict(
     },
 )
 
-GenerateBackendAPIModelsResponseResponseTypeDef = TypedDict(
-    "GenerateBackendAPIModelsResponseResponseTypeDef",
+GenerateBackendAPIModelsResponseTypeDef = TypedDict(
+    "GenerateBackendAPIModelsResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -629,8 +630,8 @@ GenerateBackendAPIModelsResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetBackendAPIModelsRequestTypeDef = TypedDict(
-    "GetBackendAPIModelsRequestTypeDef",
+GetBackendAPIModelsRequestRequestTypeDef = TypedDict(
+    "GetBackendAPIModelsRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -638,8 +639,8 @@ GetBackendAPIModelsRequestTypeDef = TypedDict(
     },
 )
 
-GetBackendAPIModelsResponseResponseTypeDef = TypedDict(
-    "GetBackendAPIModelsResponseResponseTypeDef",
+GetBackendAPIModelsResponseTypeDef = TypedDict(
+    "GetBackendAPIModelsResponseTypeDef",
     {
         "Models": str,
         "Status": StatusType,
@@ -647,16 +648,16 @@ GetBackendAPIModelsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetBackendAPIRequestTypeDef = TypedDict(
-    "_RequiredGetBackendAPIRequestTypeDef",
+_RequiredGetBackendAPIRequestRequestTypeDef = TypedDict(
+    "_RequiredGetBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
     },
 )
-_OptionalGetBackendAPIRequestTypeDef = TypedDict(
-    "_OptionalGetBackendAPIRequestTypeDef",
+_OptionalGetBackendAPIRequestRequestTypeDef = TypedDict(
+    "_OptionalGetBackendAPIRequestRequestTypeDef",
     {
         "ResourceConfig": "BackendAPIResourceConfigTypeDef",
     },
@@ -664,14 +665,14 @@ _OptionalGetBackendAPIRequestTypeDef = TypedDict(
 )
 
 
-class GetBackendAPIRequestTypeDef(
-    _RequiredGetBackendAPIRequestTypeDef, _OptionalGetBackendAPIRequestTypeDef
+class GetBackendAPIRequestRequestTypeDef(
+    _RequiredGetBackendAPIRequestRequestTypeDef, _OptionalGetBackendAPIRequestRequestTypeDef
 ):
     pass
 
 
-GetBackendAPIResponseResponseTypeDef = TypedDict(
-    "GetBackendAPIResponseResponseTypeDef",
+GetBackendAPIResponseTypeDef = TypedDict(
+    "GetBackendAPIResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -682,8 +683,8 @@ GetBackendAPIResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetBackendAuthRequestTypeDef = TypedDict(
-    "GetBackendAuthRequestTypeDef",
+GetBackendAuthRequestRequestTypeDef = TypedDict(
+    "GetBackendAuthRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -691,8 +692,8 @@ GetBackendAuthRequestTypeDef = TypedDict(
     },
 )
 
-GetBackendAuthResponseResponseTypeDef = TypedDict(
-    "GetBackendAuthResponseResponseTypeDef",
+GetBackendAuthResponseTypeDef = TypedDict(
+    "GetBackendAuthResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -703,8 +704,8 @@ GetBackendAuthResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetBackendJobRequestTypeDef = TypedDict(
-    "GetBackendJobRequestTypeDef",
+GetBackendJobRequestRequestTypeDef = TypedDict(
+    "GetBackendJobRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -712,8 +713,8 @@ GetBackendJobRequestTypeDef = TypedDict(
     },
 )
 
-GetBackendJobResponseResponseTypeDef = TypedDict(
-    "GetBackendJobResponseResponseTypeDef",
+GetBackendJobResponseTypeDef = TypedDict(
+    "GetBackendJobResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -727,14 +728,14 @@ GetBackendJobResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetBackendRequestTypeDef = TypedDict(
-    "_RequiredGetBackendRequestTypeDef",
+_RequiredGetBackendRequestRequestTypeDef = TypedDict(
+    "_RequiredGetBackendRequestRequestTypeDef",
     {
         "AppId": str,
     },
 )
-_OptionalGetBackendRequestTypeDef = TypedDict(
-    "_OptionalGetBackendRequestTypeDef",
+_OptionalGetBackendRequestRequestTypeDef = TypedDict(
+    "_OptionalGetBackendRequestRequestTypeDef",
     {
         "BackendEnvironmentName": str,
     },
@@ -742,14 +743,14 @@ _OptionalGetBackendRequestTypeDef = TypedDict(
 )
 
 
-class GetBackendRequestTypeDef(
-    _RequiredGetBackendRequestTypeDef, _OptionalGetBackendRequestTypeDef
+class GetBackendRequestRequestTypeDef(
+    _RequiredGetBackendRequestRequestTypeDef, _OptionalGetBackendRequestRequestTypeDef
 ):
     pass
 
 
-GetBackendResponseResponseTypeDef = TypedDict(
-    "GetBackendResponseResponseTypeDef",
+GetBackendResponseTypeDef = TypedDict(
+    "GetBackendResponseTypeDef",
     {
         "AmplifyMetaConfig": str,
         "AppId": str,
@@ -761,16 +762,16 @@ GetBackendResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetTokenRequestTypeDef = TypedDict(
-    "GetTokenRequestTypeDef",
+GetTokenRequestRequestTypeDef = TypedDict(
+    "GetTokenRequestRequestTypeDef",
     {
         "AppId": str,
         "SessionId": str,
     },
 )
 
-GetTokenResponseResponseTypeDef = TypedDict(
-    "GetTokenResponseResponseTypeDef",
+GetTokenResponseTypeDef = TypedDict(
+    "GetTokenResponseTypeDef",
     {
         "AppId": str,
         "ChallengeCode": str,
@@ -780,8 +781,8 @@ GetTokenResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredImportBackendAuthRequestTypeDef = TypedDict(
-    "_RequiredImportBackendAuthRequestTypeDef",
+_RequiredImportBackendAuthRequestRequestTypeDef = TypedDict(
+    "_RequiredImportBackendAuthRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -790,8 +791,8 @@ _RequiredImportBackendAuthRequestTypeDef = TypedDict(
         "WebClientId": str,
     },
 )
-_OptionalImportBackendAuthRequestTypeDef = TypedDict(
-    "_OptionalImportBackendAuthRequestTypeDef",
+_OptionalImportBackendAuthRequestRequestTypeDef = TypedDict(
+    "_OptionalImportBackendAuthRequestRequestTypeDef",
     {
         "IdentityPoolId": str,
     },
@@ -799,14 +800,14 @@ _OptionalImportBackendAuthRequestTypeDef = TypedDict(
 )
 
 
-class ImportBackendAuthRequestTypeDef(
-    _RequiredImportBackendAuthRequestTypeDef, _OptionalImportBackendAuthRequestTypeDef
+class ImportBackendAuthRequestRequestTypeDef(
+    _RequiredImportBackendAuthRequestRequestTypeDef, _OptionalImportBackendAuthRequestRequestTypeDef
 ):
     pass
 
 
-ImportBackendAuthResponseResponseTypeDef = TypedDict(
-    "ImportBackendAuthResponseResponseTypeDef",
+ImportBackendAuthResponseTypeDef = TypedDict(
+    "ImportBackendAuthResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -818,15 +819,15 @@ ImportBackendAuthResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListBackendJobsRequestTypeDef = TypedDict(
-    "_RequiredListBackendJobsRequestTypeDef",
+_RequiredListBackendJobsRequestRequestTypeDef = TypedDict(
+    "_RequiredListBackendJobsRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
     },
 )
-_OptionalListBackendJobsRequestTypeDef = TypedDict(
-    "_OptionalListBackendJobsRequestTypeDef",
+_OptionalListBackendJobsRequestRequestTypeDef = TypedDict(
+    "_OptionalListBackendJobsRequestRequestTypeDef",
     {
         "JobId": str,
         "MaxResults": int,
@@ -838,14 +839,14 @@ _OptionalListBackendJobsRequestTypeDef = TypedDict(
 )
 
 
-class ListBackendJobsRequestTypeDef(
-    _RequiredListBackendJobsRequestTypeDef, _OptionalListBackendJobsRequestTypeDef
+class ListBackendJobsRequestRequestTypeDef(
+    _RequiredListBackendJobsRequestRequestTypeDef, _OptionalListBackendJobsRequestRequestTypeDef
 ):
     pass
 
 
-ListBackendJobsResponseResponseTypeDef = TypedDict(
-    "ListBackendJobsResponseResponseTypeDef",
+ListBackendJobsResponseTypeDef = TypedDict(
+    "ListBackendJobsResponseTypeDef",
     {
         "Jobs": List["BackendJobRespObjTypeDef"],
         "NextToken": str,
@@ -874,14 +875,14 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredRemoveAllBackendsRequestTypeDef = TypedDict(
-    "_RequiredRemoveAllBackendsRequestTypeDef",
+_RequiredRemoveAllBackendsRequestRequestTypeDef = TypedDict(
+    "_RequiredRemoveAllBackendsRequestRequestTypeDef",
     {
         "AppId": str,
     },
 )
-_OptionalRemoveAllBackendsRequestTypeDef = TypedDict(
-    "_OptionalRemoveAllBackendsRequestTypeDef",
+_OptionalRemoveAllBackendsRequestRequestTypeDef = TypedDict(
+    "_OptionalRemoveAllBackendsRequestRequestTypeDef",
     {
         "CleanAmplifyApp": bool,
     },
@@ -889,14 +890,14 @@ _OptionalRemoveAllBackendsRequestTypeDef = TypedDict(
 )
 
 
-class RemoveAllBackendsRequestTypeDef(
-    _RequiredRemoveAllBackendsRequestTypeDef, _OptionalRemoveAllBackendsRequestTypeDef
+class RemoveAllBackendsRequestRequestTypeDef(
+    _RequiredRemoveAllBackendsRequestRequestTypeDef, _OptionalRemoveAllBackendsRequestRequestTypeDef
 ):
     pass
 
 
-RemoveAllBackendsResponseResponseTypeDef = TypedDict(
-    "RemoveAllBackendsResponseResponseTypeDef",
+RemoveAllBackendsResponseTypeDef = TypedDict(
+    "RemoveAllBackendsResponseTypeDef",
     {
         "AppId": str,
         "Error": str,
@@ -907,15 +908,15 @@ RemoveAllBackendsResponseResponseTypeDef = TypedDict(
     },
 )
 
-RemoveBackendConfigRequestTypeDef = TypedDict(
-    "RemoveBackendConfigRequestTypeDef",
+RemoveBackendConfigRequestRequestTypeDef = TypedDict(
+    "RemoveBackendConfigRequestRequestTypeDef",
     {
         "AppId": str,
     },
 )
 
-RemoveBackendConfigResponseResponseTypeDef = TypedDict(
-    "RemoveBackendConfigResponseResponseTypeDef",
+RemoveBackendConfigResponseTypeDef = TypedDict(
+    "RemoveBackendConfigResponseTypeDef",
     {
         "Error": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -960,16 +961,16 @@ SocialProviderSettingsTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredUpdateBackendAPIRequestTypeDef = TypedDict(
-    "_RequiredUpdateBackendAPIRequestTypeDef",
+_RequiredUpdateBackendAPIRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
     },
 )
-_OptionalUpdateBackendAPIRequestTypeDef = TypedDict(
-    "_OptionalUpdateBackendAPIRequestTypeDef",
+_OptionalUpdateBackendAPIRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendAPIRequestRequestTypeDef",
     {
         "ResourceConfig": "BackendAPIResourceConfigTypeDef",
     },
@@ -977,14 +978,14 @@ _OptionalUpdateBackendAPIRequestTypeDef = TypedDict(
 )
 
 
-class UpdateBackendAPIRequestTypeDef(
-    _RequiredUpdateBackendAPIRequestTypeDef, _OptionalUpdateBackendAPIRequestTypeDef
+class UpdateBackendAPIRequestRequestTypeDef(
+    _RequiredUpdateBackendAPIRequestRequestTypeDef, _OptionalUpdateBackendAPIRequestRequestTypeDef
 ):
     pass
 
 
-UpdateBackendAPIResponseResponseTypeDef = TypedDict(
-    "UpdateBackendAPIResponseResponseTypeDef",
+UpdateBackendAPIResponseTypeDef = TypedDict(
+    "UpdateBackendAPIResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -1045,8 +1046,8 @@ UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     total=False,
 )
 
-UpdateBackendAuthRequestTypeDef = TypedDict(
-    "UpdateBackendAuthRequestTypeDef",
+UpdateBackendAuthRequestRequestTypeDef = TypedDict(
+    "UpdateBackendAuthRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -1078,8 +1079,8 @@ class UpdateBackendAuthResourceConfigTypeDef(
     pass
 
 
-UpdateBackendAuthResponseResponseTypeDef = TypedDict(
-    "UpdateBackendAuthResponseResponseTypeDef",
+UpdateBackendAuthResponseTypeDef = TypedDict(
+    "UpdateBackendAuthResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
@@ -1102,14 +1103,14 @@ UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredUpdateBackendConfigRequestTypeDef = TypedDict(
-    "_RequiredUpdateBackendConfigRequestTypeDef",
+_RequiredUpdateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendConfigRequestRequestTypeDef",
     {
         "AppId": str,
     },
 )
-_OptionalUpdateBackendConfigRequestTypeDef = TypedDict(
-    "_OptionalUpdateBackendConfigRequestTypeDef",
+_OptionalUpdateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendConfigRequestRequestTypeDef",
     {
         "LoginAuthConfig": "LoginAuthConfigReqObjTypeDef",
     },
@@ -1117,14 +1118,15 @@ _OptionalUpdateBackendConfigRequestTypeDef = TypedDict(
 )
 
 
-class UpdateBackendConfigRequestTypeDef(
-    _RequiredUpdateBackendConfigRequestTypeDef, _OptionalUpdateBackendConfigRequestTypeDef
+class UpdateBackendConfigRequestRequestTypeDef(
+    _RequiredUpdateBackendConfigRequestRequestTypeDef,
+    _OptionalUpdateBackendConfigRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateBackendConfigResponseResponseTypeDef = TypedDict(
-    "UpdateBackendConfigResponseResponseTypeDef",
+UpdateBackendConfigResponseTypeDef = TypedDict(
+    "UpdateBackendConfigResponseTypeDef",
     {
         "AppId": str,
         "BackendManagerAppId": str,
@@ -1134,16 +1136,16 @@ UpdateBackendConfigResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateBackendJobRequestTypeDef = TypedDict(
-    "_RequiredUpdateBackendJobRequestTypeDef",
+_RequiredUpdateBackendJobRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendJobRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "JobId": str,
     },
 )
-_OptionalUpdateBackendJobRequestTypeDef = TypedDict(
-    "_OptionalUpdateBackendJobRequestTypeDef",
+_OptionalUpdateBackendJobRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendJobRequestRequestTypeDef",
     {
         "Operation": str,
         "Status": str,
@@ -1152,14 +1154,14 @@ _OptionalUpdateBackendJobRequestTypeDef = TypedDict(
 )
 
 
-class UpdateBackendJobRequestTypeDef(
-    _RequiredUpdateBackendJobRequestTypeDef, _OptionalUpdateBackendJobRequestTypeDef
+class UpdateBackendJobRequestRequestTypeDef(
+    _RequiredUpdateBackendJobRequestRequestTypeDef, _OptionalUpdateBackendJobRequestRequestTypeDef
 ):
     pass
 
 
-UpdateBackendJobResponseResponseTypeDef = TypedDict(
-    "UpdateBackendJobResponseResponseTypeDef",
+UpdateBackendJobResponseTypeDef = TypedDict(
+    "UpdateBackendJobResponseTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
